/******************************************************************************
	dislformat: convert old disl data file format to new data file format

	usage: dislformat < oldDataFormat > newDataFormat

	compile: cc -g -o dislformat dislformat.c
******************************************************************************/
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>

#define REGULAR_FILE 0100000
#define PIPE         0010000

struct bench_mark
         {
         char   name[20];    /* name of benchmark           */
         double xLon;        /* longitude or x of benchmark */
         double yLat;        /* latidute  or y of benchmark */
         double zEle;        /* elevation or z of benchmark */
         double xDat;        /* observed x movement         */
         double yDat;        /* observed y movement         */
         double zDat;        /* observed z movement         */
         double xMod;        /* modeled  x movement         */
         double yMod;        /* modeled  y movement         */
         double zMod;        /* modeled  z movement         */
         double xErr;        /* error in x data             */
         double yErr;        /* error in y data             */
         double zErr;        /* error in z data             */
         };

main()
{
	struct stat statbuf;
	struct bench_mark bm;
	double x, y, z, xdat, ydat, zdat, xmod, ymod, zmod;
	int first;
	char line[258], format[82], name[8];

	/* check usage */
	fstat(0, &statbuf);
	if (!((statbuf.st_mode & REGULAR_FILE) || (statbuf.st_mode & PIPE))) {
		fprintf(stderr, "Usage: dislformat < oldDataFormat > newDataFormat\n");
		exit(-1);
		}

	/* read old input format and write new input format */
	first = 1;
	while(gets(line)) {
		if (commentLine(line, 82)) {
			printf("%s\n", line);
			}
		else {
			if (first) {
      		printf("LONGITUDE LATITUDE  ELEV   NAME    ");
				printf("EDAT    NDAT    VDAT    EMOD    NMOD    VMOD\n");
      		printf("--------- --------  ----   ----    ");
				printf("----    ----    ----    ----    ----    ----\n");
				first--;
				}
			getBM(line, &bm);
			sprintf(format, "%%9. lf%%8. lf%%7. lf%%+7s%%8. lf%%8. lf%%8. lf");
			sprintf(format + 40, "%%8. lf%%8. lf%%8. lf\n\0");
			getFormat(format, 2, &bm);
			printf(format, bm.xLon, bm.yLat, bm.zEle, bm.name,
			               bm.xDat, bm.yDat, bm.zDat,
			               bm.xMod, bm.yMod, bm.zMod);
			}
		}


}




getBM(line, bm)
struct bench_mark *bm;
char            *line;
{
	char name[8];
	bm->name[0] = (char) '\0'; name[0] = (char) '\0';
	bm->xDat = 0.; bm->yDat = 0.; bm->zDat = 0.;
	bm->xLon = 0.; bm->yLat = 0.; bm->zEle = 0.;
	bm->xMod = 0.; bm->yMod = 0.; bm->zMod = 0.;
	sscanf(line +  0, "%s", name);
	strncpy(bm->name, name, 7); bm->name[7] = (char) '\0';
	sscanf(line +  7, "%lf %lf %lf", &bm->xDat, &bm->yDat, &bm->zDat);
	sscanf(line + 31, "%lf %lf %lf", &bm->yLat, &bm->xLon, &bm->zEle);
	sscanf(line + 55, "%lf %lf %lf", &bm->xMod, &bm->yMod, &bm->zMod);
}




commentLine(line, n)
int n;
char *line;
{
   int c, i;
   for(i = 0; i < n; i++) {
      c = (int) *(line + i);
      if (c ==  ' ' || c == '\t') continue;
		else if (c ==  'C') return(1);
      else if (c ==  '#') return(1);
      else if (c == '\n') return(1);
      else if (c == '\0') return(1);
      return(0);
      }
   return(1);
}




getFormat(format, mDigit, bm)
struct  bench_mark *bm;
int     mDigit;
char   *format;
{
   format[ 3] = (char) (getMDigit(bm->xLon, 9,           4) + '0');
   format[ 9] = (char) (getMDigit(bm->yLat, 8,           4) + '0');
   format[15] = (char) (getMDigit(bm->zEle, 7,           2) + '0');
   format[25] = (char) (getMDigit(bm->xDat, 8,           2) + '0');
   format[31] = (char) (getMDigit(bm->yDat, 8,           2) + '0');
   format[37] = (char) (getMDigit(bm->zDat, 8,           2) + '0');
   format[43] = (char) (getMDigit(bm->xMod, 8,      mDigit) + '0');
   format[49] = (char) (getMDigit(bm->yMod, 8,      mDigit) + '0');
   format[55] = (char) (getMDigit(bm->zMod, 8,      mDigit) + '0');
}





int
getMDigit(value, field, mDigit)
double value;
int    field, mDigit;
{
   int max, n;
   char fTest[20], mTest[20];
   sprintf(fTest, "%%%d.%dlf\0", field, mDigit);
   sprintf(mTest, fTest, value);
   max = (mTest[0] == (char) '-' || mTest[0] == ' ') ? (field) : (field - 1);
   if ((n = strlen(mTest)) > max) if ((mDigit -= n - max) < 0) mDigit = 0;
   return(mDigit);
}
