/******************************************************************************
	gerror: add gaussian error to gps (3D) data files

	usage: gerror [x y z] [file] < input_data_file > randomized_data_file

	x    - x error (optional but all 3 of x, y, z must be specified)
	y    - y error (optional but all 3 of x, y, z must be specified)
	z    - z error (optional but all 3 of x, y, z must be specified)
	file - optional file for new disl model values (must be striped)

	note: this uses old disl format

	compile: cc -g -o gerror -lm

	author: shawn larsen
	date:   march 1992
	where:  llnl
******************************************************************************/

#include <stdio.h>
#include <math.h>
#include <string.h>

#define XERROR       1.0     /* default x data error        */ 
#define YERROR       1.0     /* default y data error        */ 
#define ZERROR       1.0     /* default z data error        */

struct bench_mark {
         char   name[20];    /* name of benchmark           */
         double xLon;        /* longitude or x of benchmark */
         double yLat;        /* latidute  or y of benchmark */
         double zEle;        /* elevation or z of benchmark */
         double xDat;        /* observed x movement         */
         double yDat;        /* observed y movement         */
         double zDat;        /* observed z movement         */
         double xMod;        /* modeled  x movement         */
         double yMod;        /* modeled  y movement         */
         double zMod;        /* modeled  z movement         */
         double xErr;        /* error in x data             */
         double yErr;        /* error in y data             */
         double zErr;        /* error in z data             */
         };

typedef struct bench_mark             benchMark;

main(argc, argv)
int argc;
char **argv;
{
	benchMark bm;
	double gaussdev();
	double xError, yError, zError, xIn, yIn, zIn;
	int n;
	char line[82], string[26];
	FILE *dislFile;

	/* get errors */
	xError = 0.;
	yError = 0.;
	zError = 0.;
	if (argc == 4 || argc == 5) {
		xError = atof(argv[1]);
		yError = atof(argv[2]);
		zError = atof(argv[3]);
		}
	if (xError <= 0.) xError = XERROR;
	if (yError <= 0.) yError = YERROR;
	if (zError <= 0.) zError = ZERROR;

	/* get input file */
	if (argc == 2 || argc == 5) {
		if (argc == 2) dislFile = fopen(argv[1], "r");
		if (argc == 5) dislFile = fopen(argv[4], "r");
		if (dislFile == NULL) {
			fprintf(stderr, "ERROR: can't open disl file \"%s\"\n", argv[4]);
			exit(-1);
			}
		}

	/* read input file */
	while(fgets()) {
		}

	/* print header line */
	printf("#name xdat  ydat  zdat  xLon  yLat  zEle  xErr  yErr  zErr\n");

	/* read input file and add random errors */
	while(gets(line)) {
		if (commentLine(line, 82)) continue;
		bm.xMod = 0.0; bm.yMod = 0.0; bm.zMod = 0.0;
		strncpy(bm.name, line, 7); bm.name[7] = (char) '\0';
		strncpy(string, line + 7, 25);
		n = 
		sscanf(string   , "%lf %lf %lf", &xIn ,    &yIn ,    &zIn );  
		sscanf(line + 31, "%lf %lf %lf", &bm.xLon, &bm.yLat, &bm.zEle);  
		sscanf(line + 55, "%lf %lf %lf", &bm.xMod, &bm.yMod, &bm.zMod);  
		bm.xErr = (bm.xMod > 0.) ? bm.xMod : xError;
		bm.yErr = (bm.yMod > 0.) ? bm.yMod : yError;
		bm.zErr = (bm.zMod > 0.) ? bm.zMod : zError;
		bm.xMod = (float) gaussdev()*bm.xErr;
		bm.yMod = (float) gaussdev()*bm.yErr;
		bm.zMod = (float) gaussdev()*bm.zErr;
		printf("%7s%8.2lf%8.2lf%8.2lf%9.4lf%8.4lf%7.1lf%8.1lf%8.1lf%8.1lf\n",
				  bm.name, bm.xMod, bm.yMod, bm.zMod, bm.xLon, bm.yLat, bm.zEle,
		                 bm.xErr, bm.yErr, bm.zErr);
		}

	/* close input disl file */
	if (dislFile) fclose(dislFile);

}



/******************************************************************************
	gaussdev: random gaussian distributed deviation of UNIT error about 0.

	follows gasdev in numerical recipes (p. 203, fortran)
	returns deviation (double)

	usage:  deviation = gaussdev()

	return: unit random deviation about 0 (double)

	compile: cc -g -c gaussdev.c -lm

	author: shawn larsen
	date:   september 1990
	where:  caltech
******************************************************************************/

#include <stdio.h>
#include <math.h>

static int first = 1;

double gaussdev()
{
	double drand48();
	void srand48();
	int getpid();
	long seed;
	double v1, v2, r, d;
	int i;

	if (first) {
		seed = (long) getpid();
		srand48(seed);
		first = 0;
		}

	do {
		v1 =  2.*drand48() - 1.;
		v2 =  2.*drand48() - 1.;
		r = v1*v1 + v2*v2;
		}
	while (r >= 1.);
	d = v1*sqrt(-2.*log(r)/r);

	return(d);

}



commentLine(line, n)
int n;
char *line;
{
   int c, i;
   for(i = 0; i < n; i++) {
      c = (int) *(line + i);
      if (c ==  ' ' || c == '\t') continue;
      else if (c ==  '#') return(1);
      else if (c == '\n') return(1);
      else if (c == '\0') return(1);
      return(0);
      }
   return(1);
}
