/******************************************************************************
	sacutil.h: include file for SAC utility routines

	author: shawn larsen
	date:   june 1992
	where:  llnl
******************************************************************************/



/*****************
GENERAL PARAMETERS
*****************/

#define SACWORDS                   158  /* number of words in SAC header    */ 
#define WORDSIZE                     4  /* word size (bytes)                */
#define SACSIZE    (SACWORDS*WORDSIZE)  /* number of bytes in SAC header    */
#define HVERSION                     6  /* header version number            */
#define INTERNAL                     0  /* value of some internal variables */
#define OVERWRITE                    1  /* file overwrite permission        */
#define CALDA                        1  /* calculate from coordinates       */ 



/***********************
NUMBER OF EACH DATA TYPE
***********************/

#define FWORDS     70         /* number of floats   (words) */
#define IWORDS     35         /* number of ints     (words) */
#define LWORDS      5         /* number of logicals (words) */ 
#define KWORDS     48         /* number of character words  */



/*************************
DATA TYPE UNDEFINED VALUES 
*************************/

#define FVALUE   -12345.0      /* undefined floating point value */
#define IVALUE   -12345        /* undefined integer        value */
#define LVALUE        0        /* undefined logical        value */
#define KVALUE  "-12345  "     /* undefined character      value */



/********************************
WORD OFFSETS OF SPECIAL VARIABLES
********************************/

#define DNVHDR       76       /* offset (words) of header version number */
#define DINTERNAL4   77       /* offset (words) of 4th internal variable */
#define DINTERNAL5   78       /* offset (words) of 5th internal variable */
#define DLOVROK     107       /* offset (words) of file overwrite flag   */
#define DCALDA      108       /* offset (words) calculate flag           */



/********************************
WORD OFFSETS OF CERTAIN VARIABLES
********************************/

#define DDELTA      0         /* offset (words) of delta  */
#define DDEPMIN     1         /* offset (words) of depmin */ 
#define DDEPMAX     2         /* offset (words) of depmax */
#define DB          5         /* offset (words) of b      */
#define DE          6         /* offset (words) of e      */
#define DNPTS      79         /* offset (words) of npts   */
#define DIFTYPE    85         /* offset (words) of iftype */
#define DLEVEN    105         /* offset (words) of leven  */



/*********************
SHORT HEADER STRUCTURE
*********************/

struct sac_parameter
				{
				float   delta;     /* type increment   */
				float  depmin;     /* minimum value    */
				float  depmax;     /* maximum value    */
				float       b;     /* starting time    */
				float       e;     /* ending   time    */
				int      npts;     /* number of points */
				int    iftype;     /* type of file     */
				int     leven;     /* spacing of data  */
				};



/*************
REDECLARATIONS
*************/

typedef struct sac_parameter SACParameter;
