/****************************************************************************
This file contains usage strings for dislocation modeling.

   *******************************************************************
   * (c) Copyright 1992 The Regents of the University of California. *
   *     All Rights Reserved.                                        *
   *                                                                 *
   *     This work was produced under the sponsorship of the         *
   *     United States Department of Energy.                         *
   *     The Government retains certain rights therein.              *
   *******************************************************************

author: shawn larsen
date:   august 1992
where:  llnl   
****************************************************************************/


#include <sys/types.h>
#include <sys/stat.h>

#define REGULAR_FILE 0100000
#define PIPE         0010000



/*************
USAGE FOR DISL 
*************/

char *dislUsage[] = {
	"Usage:  disl [optional parameters] < inputFile > outputFile\n",
	"\n",
	"Parameters:\n",
	"----------\n",
   "  xy         - xy input/output (instead of lat/lon)\n",
   "  mdigit     - modeled digits right of decimal\n",
	"  residual   - output residual (observed - calculated) instead of model\n", 
	"\n",
   "Example Input File:\n",
   "------------------\n",
   "\n",
   "  options xy=0 mdigit=2 residual=0\n", 
   "  fault s  100.0  23.5  0.0  10.0  90.0 -115.7433  32.9717  130.0  sshf\n",
   "  fault s  -40.0  23.0  0.0  10.0  90.0 -115.7383  33.1300   45.0  elmr\n",
	"  profile x1=-115.5 x2=-114.5 y1=34.0 y2=34.1  n=10     ", 
	"  name=\"profile\"\n",
	"  contour x1=-115.0 x2=-114.0 y1=34.0 y2=35.0 nx=5  ny=5", 
	"  name=\"contour\"\n",
	"  benchmarks file=\"disl.in\"  set 1\n", 
	"-115.7611 32.9506  15.50<--L589  -18.66   42.10    1.80",
	"  -22.66   29.24   -0.73\n",
	"-115.7962 32.7901 -34.50   OCOT    5.00   10.00    0.00",
	"    0.97    7.98    0.34\n",
	"  benchmarks                   set 2\n",
	"-118.1733 34.2051 424.30   JPLM   -1.10    0.31    0.00",
	"    0.50    0.30 1001.00\n",
	"-116.8892 35.4251 986.70   GOLD   -0.25   -1.47    0.47",
	"    0.50    0.30 1001.00\n",
	"  stop\n",
	"-117.2524 32.8675   8.30   SIO2    1.03    1.05    0.57",
	"    0.50    0.30 1001.00\n",
	"  linelengths file=\"\"\n",
	"-115.7962 32.7901 -34.50-115.7611 32.9506 -15.50<--OCOT-L589-->",
	"  130.00    1.00\n", 
	"-115.7962 32.7901 -34.50-115.7611 32.9506 -15.50<--OCOT-L589-->",
	"  131.00    1.50\n", 
	NULL,
	};



/*************
USAGE FOR DISN
*************/

char *disnUsage[] = {
   "Usage:  disn [optional parameters] < inputFile > outputFile\n",
   "\n",
   "Parameters:\n",
   "----------\n",
   "  xy         - xy input/output (instead of lat/lon)\n",
   "  stress     - stress/strain output mode\n",
   "  mdigit     - modeled digits right of decimal\n",
   "  increment  - increment (km) for numerical strain\n",
   "\n",
   "Example Input File:\n",
   "------------------\n",
   "\n",
   "  options xy=0 stress=1 mdigit=2 increment=0.001\n",
   "  fault s  100.0  23.5  0.0  10.0  90.0 -115.7433  32.9717  130.0  sshf\n",
   "  fault s  -40.0  23.0  0.0  10.0  90.0 -115.7383  33.1300   45.0  elmr\n",
   "  point  x=-115.           y=34.         z=5.          name=\"point\"\n",
   "  datum x1=-116. x2=-115. y1=33. y2=34.  z=5.          name=\"datum\" ",
	"nx=10 ny=10\n",
   "  block x1=-116. x2=-115. y1=33. y2=34. z1=5.0 z2=10.0 name=\"block1\" ",
	"\\\n        nx=10 ny=10 nz=5\n",
	"  plane l=25. d=0. w=10. dp=90. x=-116.5 y=34.5 az=134. nm=\"plane0\" ",
	"nx=25 ny=10\n",
   "  plane length=25.0   depth=0.0 width=10. dip=90. x=-116.5 y=34.5    ",
	"\\\n        azimuth=134.0 name=\"plane1\" nx=25 ny=10\n",
	NULL,
	};



/*************
USAGE FOR DISF
*************/

char *disfUsage[] = {
   "Usage:  disf [optional parameters] < inputFile > outputFile\n",
   "\n",
   "Parameters:\n",
   "----------\n",
   "  xy         - xy input/output (instead of lat/lon)\n",
   "  increment  - increment (km) for numerical strain\n",
	"  t          - number of time steps\n",
	"  dt         - time step increment (years)\n",
   "\n",
   "Example Input File:\n",
   "------------------\n",
   "\n",
   "  options xy=0 increment=0.001 t=10000 dt=1.0\n",
   "  fault s  100.0  23.5  0.0  10.0  90.0 -115.7433  32.9717  130.0  sshf\n",
   "  fault s  -40.0  23.0  0.0  10.0  90.0 -115.7383  33.1300   45.0  elmr\n",
	NULL,
	};



/***************
USAGE FOR GPSINV
***************/

char *gpsinvUsage[] = {
   "Usage:  gpsinv [optional parameters] < inputFile > outputFile\n",
   "\n",
   "Parameters:\n",
   "----------\n",
   "  xy         - xy input/output (instead of lat/lon)\n",
   "\n",
   "Example Input File:\n",
   "------------------\n",
   "\n",
   "  options xy=0 increment=0.001 t=10000 dt=1.0\n",
	NULL,
	};



/****************
USAGE FOR DISLFLT
****************/

char *dislfltUsage[] = {
   "Usage:  dislflt [optional parameters] < dislOutputFile > plotoutputFile\n",
   "\n",
   "Parameters:\n",
   "----------\n",
   "  xy         - xy input/output (instead of lat/lon)\n",
   "\n",
   "Example Input File:\n",
   "------------------\n",
   "\n",
   "  options xy=0 increment=0.001 t=10000 dt=1.0\n",
	NULL,
	};



/**************
USAGE FOR GDISL 
**************/

char *gdislUsage[] = {
	"Usage:  gdisl [optional parameters] < inputFile > outputFile\n",
	"\n",
	"Parameters:\n",
	"----------\n",
	"  xy      - flag for xy input\n",
	"  xerror  - default random error in x direction (east)\n",
	"  yerror  - default random error in y direction (north)\n",
	"  zerror  - default random error in z direction (vertical)\n",
	"  derror  - default random error in   length    (line-length)\n",
	"  seed    - seed number for random number generator (default pid)\n",
	"\n",
   "Example Input File:\n",
   "------------------\n",
   "\n",
   "  options xerror=2.0 yerror=2.0 zerror=4.0 seed=10\n", 
   "  fault s  100.0  23.5  0.0  10.0  90.0 -115.7433  32.9717  130.0  sshf\n",
   "  fault s  -40.0  23.0  0.0  10.0  90.0 -115.7383  33.1300   45.0  elmr\n",
	"  benchmarks file=\"gdisl.in\"  set 1\n", 
	"-115.7611 32.9506  15.50<--L589  -18.66   42.10    1.80",
	"  -22.66   29.24   -0.73\n",
	"-115.7962 32.7901 -34.50   OCOT    5.00   10.00    0.00",
	"    0.97    7.98    0.34\n",
	"  benchmarks                   set 2\n",
	"-118.1733 34.2051 424.30   JPLM   -1.10    0.31    0.00",
	"    0.50    0.30 1001.00\n",
	"-116.8892 35.4251 986.70   GOLD   -0.25   -1.47    0.47",
	"    0.50    0.30 1001.00\n",
	"  stop\n",
	"-117.2524 32.8675   8.30   SIO2    1.03    1.05    0.57",
	"    0.50    0.30 1001.00\n",
	"  linelengths file=\"\"\n",
	"-115.7962 32.7901 -34.50-115.7611 32.9506 -15.50<--OCOT-L589-->",
	"  130.00    1.00\n", 
	"-115.7962 32.7901 -34.50-115.7611 32.9506 -15.50<--OCOT-L589-->",
	"  131.00    1.50\n", 
	NULL,
	};


/*************
USAGE FOR DIST 
*************/

char *distUsage[] = {
	"Usage:  dist [optional parameters] < inputFile > outputFile\n",
	"\n",
	"Parameters:\n",
	"----------\n",
   "  xy         - xy input/output (instead of lat/lon)\n",
   "  mdigit     - modeled digits right of decimal\n",
	"  residual   - output residual (observed - calculated) instead of model\n", 
	"\n",
   "Example Input File:\n",
   "------------------\n",
   "\n",
   "  options xy=0 mdigit=2 residual=0\n", 
   "  fault s  100.0  23.5  0.0  10.0  90.0 -115.7433  32.9717  130.0  sshf\n",
   "  fault s  -40.0  23.0  0.0  10.0  90.0 -115.7383  33.1300   45.0  elmr\n",
	"  profile x1=-115.5 x2=-114.5 y1=34.0 y2=34.1  n=10     ", 
	"  name=\"profile\"\n",
	"  contour x1=-115.0 x2=-114.0 y1=34.0 y2=35.0 nx=5  ny=5", 
	"  name=\"contour\"\n",
	"  benchmarks file=\"disl.in\"  set 1\n", 
	"-115.7611 32.9506  15.50<--L589  -18.66   42.10    1.80",
	"  -22.66   29.24   -0.73\n",
	"-115.7962 32.7901 -34.50   OCOT    5.00   10.00    0.00",
	"    0.97    7.98    0.34\n",
	"  benchmarks                   set 2\n",
	"-118.1733 34.2051 424.30   JPLM   -1.10    0.31    0.00",
	"    0.50    0.30 1001.00\n",
	"-116.8892 35.4251 986.70   GOLD   -0.25   -1.47    0.47",
	"    0.50    0.30 1001.00\n",
	"  stop\n",
	"-117.2524 32.8675   8.30   SIO2    1.03    1.05    0.57",
	"    0.50    0.30 1001.00\n",
	"  linelengths file=\"\"\n",
	"-115.7962 32.7901 -34.50-115.7611 32.9506 -15.50<--OCOT-L589-->",
	"  130.00    1.00\n", 
	"-115.7962 32.7901 -34.50-115.7611 32.9506 -15.50<--OCOT-L589-->",
	"  131.00    1.50\n", 
	NULL,
	};

